@@ -347,15 +347,22 @@ class DobissTempSensor(DobissSensor):
                         return cal["name"]
         return None
 
+    @property
+    def manual_mode(self):
+        # time == -30 means automatic mode
+        return self.time != -30
+
     async def set_temperature(self, temp):
-        await self.set_temp_timer(temperature = temp)
+        # if we explicitly set a temperature, and the mode is currently auto, switch to manual mode
+        time = self.time
+        if not self.manual_mode:
+            time = 30
+        await self.set_temp_timer(temperature=temp, minutes=time)
 
     async def set_manual_mode(self, manual = True):
         if manual:
-            time = self.time
-            if time == -30:
-                time = 30
-            await self.set_temp_timer(minutes = time)
+            if not self.manual_mode:
+                await self.set_temp_timer(minutes = 30)
         else:
             await self.set_temp_timer(minutes = -30)
 
